JobAlbumArt class

The .jpg or .png file associated with an audio file.

Constructors

JobAlbumArt({List<Artwork>? artwork, String? mergePolicy})
JobAlbumArt.fromJson(Map<String, dynamic> json)
factory

Properties

artwork → List<Artwork>?
The file to be used as album art. There can be multiple artworks associated with an audio file, to a maximum of 20. Valid formats are .jpg and .png
final
hashCode → int
The hash code for this object.
no setterinherited
mergePolicy → String?
A policy that determines how Elastic Transcoder handles the existence of multiple album artwork files.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited