Thumbnails class
Thumbnails for videos.
Constructors
Properties
- aspectRatio → String?
-
To better control resolution and aspect ratio of thumbnails, we recommend
that you use the values
MaxWidth,MaxHeight,SizingPolicy, andPaddingPolicyinstead ofResolutionandAspectRatio. The two groups of settings are mutually exclusive. Do not use them together.final - format → String?
-
The format of thumbnails, if any. Valid values are
jpgandpng.final - hashCode → int
-
The hash code for this object.
no setterinherited
- interval → String?
-
The approximate number of seconds between thumbnails. Specify an integer
value.
final
- maxHeight → String?
-
The maximum height of thumbnails in pixels. If you specify auto, Elastic
Transcoder uses 1080 (Full HD) as the default value. If you specify a
numeric value, enter an even integer between 32 and 3072.
final
- maxWidth → String?
-
The maximum width of thumbnails in pixels. If you specify auto, Elastic
Transcoder uses 1920 (Full HD) as the default value. If you specify a
numeric value, enter an even integer between 32 and 4096.
final
- paddingPolicy → String?
-
When you set
PaddingPolicytoPad, Elastic Transcoder may add black bars to the top and bottom and/or left and right sides of thumbnails to make the total size of the thumbnails match the values that you specified for thumbnailMaxWidthandMaxHeightsettings.final - resolution → String?
-
To better control resolution and aspect ratio of thumbnails, we recommend
that you use the values
MaxWidth,MaxHeight,SizingPolicy, andPaddingPolicyinstead ofResolutionandAspectRatio. The two groups of settings are mutually exclusive. Do not use them together.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sizingPolicy → String?
-
Specify one of the following values to control scaling of thumbnails:
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited